@@ -212,7 +212,7 @@ bool gprs_rlcmac_ul_tbf_can_request_new_ul_tbf(const struct gprs_rlcmac_ul_tbf *
 		return false;
 
 	/* "TBF Est field is set to '1'"" */
-	if (!ul_tbf->state_fsm.rx_final_pkt_ul_ack_nack_has_tbf_est)
+	if (!ul_tbf->state_fsm.rx_final_pkt_ul_ack_nack.has_tbf_est)
 		return false;
 
 	/* the mobile station has new data to transmit */
@@ -305,9 +305,9 @@ static void gprs_rlcmac_ul_tbf_update_tx_cs(struct gprs_rlcmac_ul_tbf *ul_tbf, e
 }
 
 int gprs_rlcmac_ul_tbf_handle_pkt_ul_ack_nack(struct gprs_rlcmac_ul_tbf *ul_tbf,
-					      const RlcMacDownlink_t *dl_block)
+					      const struct gprs_rlcmac_dl_block_ind *dlbi)
 {
-	const Packet_Uplink_Ack_Nack_t *ack = &dl_block->u.Packet_Uplink_Ack_Nack;
+	const Packet_Uplink_Ack_Nack_t *ack = &dlbi->dl_block.u.Packet_Uplink_Ack_Nack;
 	const PU_AckNack_GPRS_t *gprs = &ack->u.PU_AckNack_GPRS_Struct;
 	const Ack_Nack_Description_t *ack_desc = &gprs->Ack_Nack_Description;
 	int bsn_begin, bsn_end;
@@ -321,8 +321,7 @@ int gprs_rlcmac_ul_tbf_handle_pkt_ul_ack_nack(struct gprs_rlcmac_ul_tbf *ul_tbf,
 	};
 	int rc;
 	struct tbf_ul_ass_ev_rx_ul_ack_nack ev_ack = {
-		.final_ack = ack_desc->FINAL_ACK_INDICATION,
-		.tbf_est = (gprs->Exist_AdditionsR99 && gprs->AdditionsR99.TBF_EST),
+		.dlbi = dlbi,
 	};
 
 	num_blocks = gprs_rlcmac_decode_gprs_acknack_bits(
@@ -352,14 +351,13 @@ int gprs_rlcmac_ul_tbf_handle_pkt_ul_ack_nack(struct gprs_rlcmac_ul_tbf *ul_tbf,
 }
 
 int gprs_rlcmac_ul_tbf_handle_pkt_ul_ass(struct gprs_rlcmac_ul_tbf *ul_tbf,
-					 const struct osmo_gprs_rlcmac_prim *rlcmac_prim,
-					 const RlcMacDownlink_t *dl_block)
+					 const struct gprs_rlcmac_dl_block_ind *dlbi)
 {
 	int rc;
 	struct tbf_ul_ass_ev_rx_pkt_ul_ass_ctx d = {
-		.ts_nr = rlcmac_prim->l1ctl.pdch_data_ind.ts_nr,
-		.fn = rlcmac_prim->l1ctl.pdch_data_ind.fn,
-		.dl_block = dl_block,
+		.ts_nr = dlbi->ts_nr,
+		.fn = dlbi->fn,
+		.dl_block = &dlbi->dl_block,
 	};
 
 	rc = osmo_fsm_inst_dispatch(ul_tbf->ul_ass_fsm.fi, GPRS_RLCMAC_TBF_UL_ASS_EV_RX_PKT_UL_ASS, &d);
@@ -557,7 +555,7 @@ static void blk_count_append_llc(struct blk_count_state *st, unsigned int llc_pa
 /* Returned as early return from function when amount of RLC blocks goes clearly over BS_CV_MAX */
 #define BLK_COUNT_TOOMANY 0xff
 /* We cannot early-check if extra_li0=true, since there may temporarily have too many rlc blocks: */
-#define BLK_COUNT_EARLY_CHECK_TOOMANY(st) (!(st)->extra_li0) && blk_count_to_x(st) > (st)->bs_cv_max)
+#define BLK_COUNT_EARLY_CHECK_TOOMANY(st) (!((st)->extra_li0) && blk_count_to_x(st) > (st)->bs_cv_max)
 static uint8_t blk_count_append_llc_prio_queue(struct blk_count_state *st, const struct gprs_llc_prio_queue *pq)
 {
 	struct msgb *msg;
@@ -565,7 +563,7 @@ static uint8_t blk_count_append_llc_prio_queue(struct blk_count_state *st, const
 	llist_for_each_entry(msg, &pq->queue, list) {
 		blk_count_append_llc(st, msgb_l2len(msg));
 		/* We cannot early-check if extra_li0=true, since there may temporarily have too many rlc blocks. */
-		if (BLK_COUNT_EARLY_CHECK_TOOMANY(st)
+		if (BLK_COUNT_EARLY_CHECK_TOOMANY(st))
 			return BLK_COUNT_TOOMANY; /* early return, not entering countdown procedure */
 	}
 	return 0;
@@ -594,7 +592,7 @@ static uint8_t gprs_rlcmac_ul_tbf_calculate_cv(const struct gprs_rlcmac_ul_tbf *
 	/* First of all, the current LLC frame in progress: */
 	if (ul_tbf->llc_tx_msg) {
 		blk_count_append_llc(&st, msgb_length(ul_tbf->llc_tx_msg));
-		if (BLK_COUNT_EARLY_CHECK_TOOMANY(&st)
+		if (BLK_COUNT_EARLY_CHECK_TOOMANY(&st))
 			goto done; /* early return, not entering countdown procedure */
 	}
 
